==> haskell-integer-logarithms-1.0.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.1
id: integer-logarithms-1.0.1-BMmDc9fXSmWBX4AQeoakwE
key: integer-logarithms-1.0.1-BMmDc9fXSmWBX4AQeoakwE
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
stability: Provisional
homepage: https://github.com/phadej/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
author: Daniel Fischer
exposed: True
exposed-modules:
    Math.NumberTheory.Logarithms Math.NumberTheory.Powers.Integer
    Math.NumberTheory.Powers.Natural GHC.Integer.Logarithms.Compat
abi: 6d937c35bb60cffbb0724540fe7b0bc5
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/integer-logarithms-1.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/integer-logarithms-1.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/integer-logarithms-1.0.1
hs-libraries: HSinteger-logarithms-1.0.1-BMmDc9fXSmWBX4AQeoakwE
depends:
    array-0.5.1.1 base-4.9.0.0 ghc-prim-0.5.0.0 integer-gmp-1.0.0.1
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-logarithms-1.0.2-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: integer-logarithms
version: 1.0.2
id: integer-logarithms-1.0.2-IDuUvOgHWcrIzD9yrr4lsA
key: integer-logarithms-1.0.2-IDuUvOgHWcrIzD9yrr4lsA
license: MIT
copyright: (c) 2011 Daniel Fischer
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
stability: Provisional
homepage: https://github.com/phadej/integer-logarithms
synopsis: Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.
    .
    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.
category: Math, Algorithms, Number Theory
author: Daniel Fischer
exposed: True
exposed-modules:
    Math.NumberTheory.Logarithms Math.NumberTheory.Powers.Integer
    Math.NumberTheory.Powers.Natural GHC.Integer.Logarithms.Compat
abi: 4e273519222fc9f1bca0ecece013a0f7
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/integer-logarithms-1.0.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/integer-logarithms-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/integer-logarithms-1.0.2
hs-libraries: HSinteger-logarithms-1.0.2-IDuUvOgHWcrIzD9yrr4lsA
depends:
    array-0.5.1.1 base-4.9.1.0 ghc-prim-0.5.0.0 integer-gmp-1.0.0.1
haddock-interfaces: /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock
haddock-html: /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
